from yafowil.base import factory
from yafowil.common import (
    select_extractor,
    generic_required_extractor,
    select_edit_renderer,
    select_display_renderer,
)


factory.register(
    'multiselect',
    extractors=[select_extractor, generic_required_extractor],
    edit_renderers=[select_edit_renderer],
    display_renderers=[select_display_renderer])

factory.doc['blueprint']['multiselect'] = \
"""Add-on blueprint `yafowil.widget.multiselect
<http://github.com/bluedynamics/yafowil.widget.multiselect/>`_ .
"""


factory.defaults['multiselect.multivalued'] = True
factory.defaults['multiselect.size'] = None
factory.defaults['multiselect.default'] = []
factory.defaults['multiselect.format'] = 'block'
factory.defaults['multiselect.class'] = 'multiselect'



# -*- coding: utf-8 -*-
from yafowil.base import factory


DOC_MULTISELECT = """
Multiselect
-----------

Multiselect Widget using jQuery multiselect plugin.

.. code-block:: python

    vocab = (
        u'Weißburgunder',
        u'Welschriesling',
        u'Sauvingnon Blanc',
        u'Sämling',
        u'Scheurebe',
        u'Traminer',
        u'Morrilon',
        u'Muskateller',
    )
    multiselect = factory('#field:multiselect', props={
        'label': 'Select some items',
        'required': 'Selection is required',
        'vocabulary': vocab,
    })
"""

def multiselect():
    part = factory(u'fieldset', name='yafowilwidgetmultiselect')
    vocab = (
        u'Weißburgunder',
        u'Welschriesling',
        u'Sauvingnon Blanc',
        u'Sämling',
        u'Scheurebe',
        u'Traminer',
        u'Morrilon',
        u'Muskateller',
    )
    part['text'] = factory('#field:multiselect', props={
        'label': 'Select some items',
        'required': 'Selection is required',
        'vocabulary': vocab,
    })
    return {
        'widget': part,
        'doc': DOC_MULTISELECT,
        'title': 'Multiselect Widget',
    }


def get_example():
    return [
        multiselect()
    ]
